===============================
pyup
===============================

.. image:: https://img.shields.io/pypi/v/pyup.svg
        :target: https://pypi.python.org/pypi/pyup

.. image:: https://img.shields.io/travis/pyup/pyup.svg
        :target: https://travis-ci.org/pyup/pyup

.. image:: https://readthedocs.org/projects/pyup/badge/?version=latest
        :target: https://readthedocs.org/projects/pyup/?badge=latest
        :alt: Documentation Status


.. image:: https://codecov.io/github/pyupio/pyup/coverage.svg?branch=master
        :target: https://codecov.io/github/pyupio/pyup?branch=master


A tool to update all your projects requirements
